@@ -1,19 +1,22 @@
-import click
 import json
+
+import click
 from rich import print as rprint
 from rich.console import Console
+
 from pyintelowl.exceptions import IntelOwlClientException
-from ..cli._utils import (
-    ClickContext,
-    add_options,
-    json_flag_option,
-    get_action_status_text,
-)
+
 from ..cli._jobs_utils import (
     _display_all_jobs,
     _display_single_job,
-    _result_filter_and_tabular_print,
     _poll_for_job_cli,
+    _result_filter_and_tabular_print,
+)
+from ..cli._utils import (
+    ClickContext,
+    add_options,
+    get_action_status_text,
+    json_flag_option,
 )
 
 
@@ -45,12 +48,14 @@ def ls(ctx: ClickContext, status: str, as_json: bool):
     ctx.obj.logger.info("Requesting list of jobs..")
     try:
         ans = ctx.obj.get_all_jobs()
+        results = ans.get("results", [])
+        ctx.obj.logger.info(results)
         if status:
-            ans = [el for el in ans if el["status"].lower() == status.lower()]
+            ans = [el for el in results if el["status"].lower() == status.lower()]
         if as_json:
             rprint(json.dumps(ans, indent=4))
         else:
-            _display_all_jobs(ctx.obj.logger, ans)
+            _display_all_jobs(ctx.obj.logger, results)
     except IntelOwlClientException as e:
         ctx.obj.logger.fatal(str(e))
 
